/*
 *  This sketch demonstrates how to scan WiFi networks. 
 *  The API is almost the same as with the WiFi Shield library, 
 *  the most obvious difference being the different file you need to include:
 *  Arduino IDE 1.6.7 under Linux 17.3 tested on 2060204
 *  Sketch uses 236,961 bytes (54%) of program storage space. Maximum is 434,160 bytes.
 *  Global variables use 31,713 bytes (38%) of dynamic memory, leaving 50,207 bytes for local variables.
 */
#pragma GCC diagnostic ignored "-Wdeprecated-declarations"

#include "ESP8266WiFi.h"
#include <Wire.h>

// Function prototypes- forward declarations:
static void reset_display(void);
void StartUp_OLED();
void displayOn(void);
void displayOff(void);
static void clear_display(void);
static void SendChar(unsigned char data) ;
static void sendCharXY(unsigned char data, int X, int Y);
static void sendcommand(unsigned char com);
static void setXY(unsigned char row,unsigned char col);
static void sendStr(unsigned char *string);
static void sendStrXY( char *string, int X, int Y);
static void init_OLED(void);
void Draw_WIFI();
void Draw_WAVES();


void setup() 
{
  Serial.begin(115200);                   // diagnostic channel
  // Set WiFi to station mode and disconnect from an AP if it was previously connected
  WiFi.mode(WIFI_STA);
  WiFi.disconnect();
  delay(100);
  //Wire.pins(int sda, int scl), etc
  Wire.pins(0, 2);                        //on ESP-01.
  Wire.begin();
  StartUp_OLED();                         // Init Oled and fire up!
  Serial.println("OLED Init... End of Setup()");
  /*  I did not write the OLED functions... note that sendStrXY is in reality sendStrYX !!!
   *  Just deal with it: maybe original author had screen in a different orientation plane.
  sendStrXY("Line 0..........", 0, 0);  // a Full line #0 Max lines =7 for 8 total lines
  sendStrXY("Line 1.", 1, 0);
  sendStrXY("Line 2.", 2, 0);
  sendStrXY("Line 3.", 3, 0);
  sendStrXY("Line 4.", 4, 0);
  sendStrXY("Line 5.", 5, 0);
  sendStrXY("Line 6.", 6, 0);
  sendStrXY("Line 7.", 7, 0);
  delay(10000);
  */
}


void loop() 
{
  clear_display();                        // done here to simplify also setXY(0,0);
  Serial.print("Scan start. ");
  sendStrXY(">>> Scanning <<<", 0, 0);
  int n = WiFi.scanNetworks();            // WiFi.scanNetworks will return the number of networks found
  int ln = 0;                             // OLED to print line: 0 - 4
  char *WiFiSSID = "";
  Serial.print("Done: ");
  sendStrXY(">>>> Found: <<<<", ln++, 0);    // 16 Character max per line with font set
  
  if (n == 0)
  {
    Serial.println("no networks found");
    sendStrXY("No Nets in Range", ln++, 0);
    delay(2000);
    return;
  } else
  {
    Serial.print(n);
    Serial.println(" networks found");
    // sendStrXY("Scan Listing:   ", ln++, 0);
  
    for (uint8_t i = 1; i <= n; ++i)         // Print SSID and RSSI for each network found
    {
      Serial.print(i);
      Serial.print(": ");
      Serial.print(WiFi.SSID(i));
      Serial.print(" (");
      Serial.print(WiFi.RSSI(i));
      Serial.print(")");
      Serial.println((WiFi.encryptionType(i) == ENC_TYPE_NONE)?" ":"*");
    }
  
    for (uint8_t i = 1; i <= n; ++i)
    {
      if (ln % 8 == 0)
      {
          delay(3000);
          clear_display();
          ln = 0;
          sendStrXY(">>>>> more <<<<<", ln++, 0);
      }
  
      // strcpy (WiFiSSID, WiFi.SSID(i));  stricter rules are being enforced by compiler in 1.6.7
      strcpy (WiFiSSID, WiFi.SSID(i).c_str());
      // WiFiSSID = WiFiSSID + '\0';
      sendStrXY(WiFiSSID, ln++, 0);
    }
  }
  Serial.println("10 sec. delay until repeat...");
  delay(10000);                             // Wait a while before scanning again
}                                           // loop


